@@ -224,17 +224,17 @@ init_wpa_supplicant () {
 		wpa_msg verbose "wpa-driver $IF_WPA_DRIVER"
 		case "$IF_WPA_DRIVER" in
 			hostap|ipw|madwifi|ndiswrapper)
-				WPA_SUP_OPTIONS="$WPA_SUP_OPTIONS -D wext"
+				WPA_SUP_OPTIONS="$WPA_SUP_OPTIONS -D nl80211,wext"
 				wpa_msg stderr "\"$IF_WPA_DRIVER\" wpa-driver is unsupported"
-				wpa_msg stderr "using \"wext\" wpa-driver instead ..."
+				wpa_msg stderr "using \"nl80211,wext\" wpa-driver instead ..."
 				;;
 			*)
 				WPA_SUP_OPTIONS="$WPA_SUP_OPTIONS -D $IF_WPA_DRIVER"
 				;;
 		esac
 	else
-		WPA_SUP_OPTIONS="$WPA_SUP_OPTIONS -D wext"
-		wpa_msg verbose "using default driver type: wpa-driver wext"
+		WPA_SUP_OPTIONS="$WPA_SUP_OPTIONS -D nl80211,wext"
+		wpa_msg verbose "wpa-driver nl80211,wext (default)"
 	fi
 
 	if [ -n "$IF_WPA_DEBUG_LEVEL" ]; then
@@ -679,6 +679,12 @@ conf_wpa_supplicant () {
 
 		wpa_cli_do "$IF_WPA_FREQUENCY" raw \
 			set_network frequency wpa-frequency
+
+		wpa_cli_do "$IF_WPA_SCAN_FREQ" raw \
+			set_network scan_freq wpa-scan-freq
+
+		wpa_cli_do "$IF_WPA_FREQ_LIST" raw \
+			set_network freq_list wpa-freq-list
 		
 		wpa_cli_do "$IF_WPA_KEY_MGMT" raw \
 			set_network key_mgmt wpa-key-mgmt
@@ -814,9 +820,6 @@ conf_wpa_supplicant () {
 		wpa_cli_do "$IF_WPA_PAC_FILE" ascii \
 			set_network pac_file wpa-pac-file
 		
-		wpa_cli_do "$IF_WPA_MODE" raw \
-			set_network mode wpa-mode
-		
 		wpa_cli_do "$IF_WPA_PEERKEY" raw \
 			set_network peerkey wpa-peerkey
 			
